@@ -32,7 +32,7 @@ class Horde_Pack_Driver_Igbinary extends Horde_Pack_Driver
 
     /**
      */
-    static public function supported()
+    public static function supported()
     {
         return extension_loaded('igbinary');
     }
