@@ -28,7 +28,7 @@ class Horde_Pack_Driver_Json extends Horde_Pack_Driver
 
     /**
      */
-    static public function supported()
+    public static function supported()
     {
         return extension_loaded('json');
     }
